@@ -40,6 +40,7 @@ For more details check the documentation of the :class:`SimpleAutoTickerBehavior
 from typing import Callable, Dict, Optional
 
 from kivy.animation import Animation                                                        # type: ignore
+from kivy.app import App                                                                    # type: ignore
 from kivy.clock import Clock                                                                # type: ignore
 from kivy.core.window import Window                                                         # type: ignore
 from kivy.factory import Factory                                                            # type: ignore
@@ -52,10 +53,10 @@ try:        # optional requirement
     from ae.gui_app import MAX_FONT_SIZE, MIN_FONT_SIZE                                     # type: ignore
 except ImportError:                                                                         # pragma: no cover
     MIN_FONT_SIZE = 15
-    MAX_FONT_SIZE = 69
+    MAX_FONT_SIZE = 99
 
 
-__version__ = '0.1.15'
+__version__ = '0.1.16'
 
 
 class AutoFontSizeBehavior:
@@ -85,18 +86,18 @@ class AutoFontSizeBehavior:
     :attr:`auto_font_anim_duration` is a :class:`~kivy.properties.NumericProperty` and defaults to 0.9 seconds.
     """
 
-    auto_font_max_size: float = NumericProperty(MAX_FONT_SIZE)
+    auto_font_max_size: float = NumericProperty()
     """ maximum font size.
 
     :attr:`auto_font_max_size` is a :class:`~kivy.properties.NumericProperty` and defaults to
-    :data:`~ae.gui_app.MAX_FONT_SIZE`.
+    min(:data:`~ae.gui_app.MAX_FONT_SIZE`, :attr:`~ae.kivy_app.FrameworkApp.max_font_size`).
     """
 
-    auto_font_min_size: float = NumericProperty(MIN_FONT_SIZE)
+    auto_font_min_size: float = NumericProperty()
     """ minimum font size.
 
     :attr:`auto_font_min_size` is a :class:`~kivy.properties.NumericProperty` and defaults to
-    :data:`~ae.gui_app.MIN_FONT_SIZE`.
+    max(:data:`~ae.gui_app.MIN_FONT_SIZE`, :attr:`~ae.kivy_app.FrameworkApp.min_font_size`).
     """
 
     auto_font_text_spacing: float = NumericProperty('18sp')
@@ -111,7 +112,12 @@ class AutoFontSizeBehavior:
     _last_font_size: float = 0.0
 
     def __init__(self, **kwargs):
+        app = App.get_running_app()
+        self.auto_font_max_size = min(MAX_FONT_SIZE, getattr(app, 'max_font_size', MAX_FONT_SIZE))
+        self.auto_font_min_size = max(MIN_FONT_SIZE, getattr(app, 'min_font_size', MIN_FONT_SIZE))
+
         super().__init__(**kwargs)
+
         self.bind(text=self._start_font_anim)
         self.bind(width=self._start_font_anim)
         self.bind(height=self._start_font_anim)
